@@ -1,6 +1,5 @@
 package FormValidator::Lite::Constraint::Default;
 use FormValidator::Lite::Constraint;
-use List::MoreUtils 'any';
 
 rule 'NOT_NULL' => sub {
     return 0 if not defined($_);
@@ -18,7 +17,7 @@ rule 'ASCII' => sub {
 
 # {mails => [qw/mail1 mail2/]} => ['DUPLICATION']
 rule 'DUPLICATION' => sub {
-    $_->[0] eq $_->[1]
+    defined($_->[0]) && defined($_->[1]) && $_->[0] eq $_->[1]
 };
 alias 'DUPLICATION' => 'DUP';
 
